==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Zeichnung schliessen...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Do you want to save the changes you made in&lt;br&gt; the document &apos;%1&apos;?</source>
        <translation type="obsolete">Möchten Sie die gemachten Änderungen in der&lt;br&gt;Zeichnung &apos;%1&apos; speichern?</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Unbenannt %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translation>Lade...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translation>Import Fehler</translation>
    </message>
    <message>
        <source>Cannot open file

&apos;%1&apos;.

</source>
        <translation type="obsolete">Kann Datei nicht öffnen

&apos;%1&apos;.

</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translation>Kann Datei nicht öffnen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Kein geeigneter Importer gefunden. Bitte überprüfen Sie das Dateiformat und die Dateiendung.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Bitte überprüfen Sie die Zugriffsrechte, das Dateiformat und die Dateiendung.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation>Datei ist leer.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation>Zeichnung geöffnet:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translation>nur lesen</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Möchten Sie die gemachten Änderungen in der&lt;br&gt;Zeichnung &apos;%1&apos; speichern?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Ihre Änderungen gehen verloren wenn sie nicht gespeichert werden.</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Zeichnung schliessen...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Do you want to save the changes you made in&lt;br&gt; the document &apos;%1&apos;?</source>
        <translation type="obsolete">Möchten Sie die gemachten Änderungen in der&lt;br&gt;Zeichnung &apos;%1&apos; speichern?</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Unbenannt %1 [*]</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">Lade...</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+137"/>
        <source>Import Error</source>
        <translation>Import Fehler</translation>
    </message>
    <message>
        <source>Cannot open file

&apos;%1&apos;.

</source>
        <translation type="obsolete">Kann Datei nicht öffnen

&apos;%1&apos;.

</translation>
    </message>
    <message>
        <location line="-23"/>
        <source>Opening drawing:</source>
        <translation>Zeichnung öffnen:</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Cannot open file</source>
        <translation>Kann Datei nicht öffnen</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Kein geeigneter Importer gefunden. Bitte überprüfen Sie das Dateiformat und die Dateiendung.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation>Datei nicht gefunden.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Bitte überprüfen Sie die Zugriffsrechte, das Dateiformat und die Dateiendung.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation>Import fehlgeschlagen.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation>Datei ist leer.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation>Zeichnung erfolgreich geladen:</translation>
    </message>
    <message>
        <source>Opened drawing:</source>
        <translation type="vanished">Zeichnung geöffnet:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translation>nur lesen</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Möchten Sie die gemachten Änderungen in der&lt;br&gt;Zeichnung &apos;%1&apos; speichern?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Ihre Änderungen gehen verloren wenn sie nicht gespeichert werden.</translation>
    </message>
</context>
</TS>
